@@ -70,8 +70,10 @@ import javax.mail.Folder;
 import javax.mail.MessagingException;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPCommandsCollection;
+import com.openexchange.imap.config.IMAPReloadable;
 import com.openexchange.imap.services.Services;
 import com.openexchange.mail.mime.MimeMailException;
 import com.sun.mail.iap.Argument;
@@ -321,6 +323,22 @@ final class ListLsubCollection {
         return tmp.intValue();
     }
 
+    static {
+        IMAPReloadable.getInstance().addReloadable(new Reloadable() {
+
+            @Override
+            public void reloadConfiguration(final ConfigurationService configService) {
+                initAclThreshold = null;
+                initStatusThreshold = null;
+            }
+
+            @Override
+            public Map<String, String[]> getConfigFileNames() {
+                return null;
+            }
+        });
+    }
+
     private void init(final boolean clearMaps, final IMAPFolder imapFolder, final boolean doStatus, final boolean doGetAcl, final IMAPStore imapStore) throws MessagingException {
         if (clearMaps) {
             listMap.clear();
@@ -437,9 +455,7 @@ final class ListLsubCollection {
                             }
                         } catch (final Exception e) {
                             // Swallow failed STATUS command
-                            org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
-                                "STATUS command failed for " + imapFolder.getStore().toString(),
-                                e);
+                            org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug("STATUS command failed for {}", imapFolder.getStore().toString(), e);
                         }
                     }
                 }
@@ -543,29 +559,7 @@ final class ListLsubCollection {
                      * Either shared or user namespace
                      */
                     if (existsSafe(fullName, imapStore)) {
-                        final ListLsubEntryImpl lle = new ListLsubEntryImpl(entry.getValue(), true);
-                        listMap.put(fullName, lle);
-                        /*
-                         * Determine parent
-                         */
-                        final int pos = fullName.lastIndexOf(lle.getSeparator());
-                        if (pos >= 0) {
-                            /*
-                             * Non-root level
-                             */
-                            final String parentFullName = fullName.substring(0, pos);
-                            final ListLsubEntryImpl parent = listMap.get(parentFullName);
-                            {
-                                lle.setParent(parent);
-                                parent.addChild(lle);
-                            }
-                        } else {
-                            /*
-                             * Root level
-                             */
-                            lle.setParent(rootEntry);
-                            rootEntry.addChild(lle);
-                        }
+                        createLISTEntryForNamespaceFolder(fullName, entry.getValue(), rootEntry);
                     } else {
                         IMAPCommandsCollection.forceSetSubscribed(imapStore, fullName, false);
                         final ListLsubEntryImpl lle = entry.getValue();
@@ -582,6 +576,42 @@ final class ListLsubCollection {
         }
     }
 
+    private ListLsubEntryImpl createLISTEntryForNamespaceFolder(String fullName, ListLsubEntryImpl lsubEntry, ListLsubEntryImpl rootEntry) {
+        ListLsubEntryImpl lle = new ListLsubEntryImpl(lsubEntry, true);
+        listMap.put(fullName, lle);
+
+        char separator = lle.getSeparator();
+        int pos = fullName.lastIndexOf(separator);
+        if (pos >= 0) {
+            /*
+             * Non-root level
+             */
+            final String parentFullName = fullName.substring(0, pos);
+            ListLsubEntryImpl parent = listMap.get(parentFullName);
+            if (null != parent) {
+                lle.setParent(parent);
+                parent.addChild(lle);
+            } else {
+                // Parent not contained in LIST map
+                ListLsubEntryImpl parentEntry = lsubMap.get(parentFullName);
+                if (null == parentEntry) {
+                    parentEntry = new ListLsubEntryImpl(parentFullName, ATTRIBUTES_NON_EXISTING_NAMESPACE, separator, ListLsubEntry.ChangeState.UNDEFINED, true, false, Boolean.TRUE, null).setNamespace(true);
+                    lsubMap.put(parentFullName, parentEntry);
+                }
+                parent = createLISTEntryForNamespaceFolder(parentFullName, parentEntry, rootEntry);
+                lle.setParent(parent);
+                parent.addChild(lle);
+            }
+        } else {
+            /*
+             * Root level
+             */
+            lle.setParent(rootEntry);
+            rootEntry.addChild(lle);
+        }
+        return lle;
+    }
+
     private static void dropEntryFrom(final ListLsubEntryImpl lle, final ConcurrentMap<String, ListLsubEntryImpl> map) {
         final Set<ListLsubEntryImpl> tmp = new HashSet<ListLsubEntryImpl>(lle.getChildrenSet());
         for (final ListLsubEntryImpl child : tmp) {
@@ -703,6 +733,8 @@ final class ListLsubCollection {
         "\\noselect",
         "\\hasnochildren")));
 
+    private static final Set<String> ATTRIBUTES_NO_SELECT_NAMESPACE = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList("\\noselect")));
+
     private static final String ATTRIBUTE_DRAFTS = "\\drafts";
     private static final String ATTRIBUTE_JUNK = "\\junk";
     private static final String ATTRIBUTE_SENT = "\\sent";
@@ -773,7 +805,7 @@ final class ListLsubCollection {
         {
             final String sCmd = new StringBuilder(command).append(" \"\" \"*\"").toString();
             r = performCommand(protocol, sCmd);
-            LOG.debug("{} cache filled with >>{1}<< which returned {} response line(s).", (command), sCmd, r.length);
+            LOG.debug("{} cache filled with >>{}<< which returned {} response line(s).", (command), sCmd, r.length);
         }
         final Response response = r[r.length - 1];
         if (response.isOK()) {
@@ -1296,9 +1328,7 @@ final class ListLsubCollection {
                         }
                     } catch (final Exception e) {
                         // Swallow failed STATUS command
-                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
-                            "STATUS command failed for " + imapFolder.getStore().toString(),
-                            e);
+                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug("STATUS command failed for {}", imapFolder.getStore().toString(), e);
                     }
                 }
             }
@@ -1316,9 +1346,7 @@ final class ListLsubCollection {
                         }
                     } catch (final Exception e) {
                         // Swallow failed ACL command
-                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
-                            "ACL/MYRIGHTS command failed for " + imapFolder.getStore().toString(),
-                            e);
+                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug("ACL/MYRIGHTS command failed for {}", imapFolder.getStore().toString(), e);
                     }
                 }
             }
