@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -118,6 +118,13 @@ public interface IIMAPProperties extends IMailProperties {
      */
     public boolean isImapSearch();
 
+    /**
+     * Checks if IMAP search is enabled and should be forced regardless of the mail fetch limit.
+     *
+     * @return <code>true</code> if IMAP search should be forced; otherwise <code>false</code>
+     */
+    public boolean forceImapSearch();
+
     /**
      * Checks if IMAP sort is enabled.
      *
