@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -107,7 +107,6 @@ public final class IMAPSort {
      * @throws MessagingException If sort attempt fails horribly
      */
     public static int[] sortMessages(final IMAPFolder imapFolder, final int[] filter, final MailSortField sortField, final OrderDirection orderDir, final IMAPConfig imapConfig) throws MessagingException {
-        final MailSortField sortBy = sortField == null ? MailSortField.RECEIVED_DATE : sortField;
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             return new int[0];
@@ -116,6 +115,7 @@ public final class IMAPSort {
         if (imapConfig.isImapSort() || (imapConfig.getCapabilities().hasSort() && (size >= MailProperties.getInstance().getMailFetchLimit()))) {
             try {
                 // Get IMAP sort criteria
+                final MailSortField sortBy = sortField == null ? MailSortField.RECEIVED_DATE : sortField;
                 final String sortCriteria = getSortCritForIMAPCommand(sortBy, orderDir == OrderDirection.DESC);
                 if (null != sortCriteria) {
                     final int[] seqNums;
@@ -368,7 +368,7 @@ public final class IMAPSort {
 
         @Override
         public Object doCommand(final IMAPProtocol p) throws ProtocolException {
-            final String command = new com.openexchange.java.StringAllocator("UID SORT (").append(descending ? "REVERSE " : "").append("ARRIVAL) UTF-8 ALL").toString();
+            final String command = new StringBuilder("UID SORT (").append(descending ? "REVERSE " : "").append("ARRIVAL) UTF-8 ALL").toString();
             final Response[] r = IMAPCommandsCollection.performCommand(p, command);
             final Response response = r[r.length - 1];
             final TLongList list = new TLongArrayList(256);
