@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,11 @@
 
 package com.openexchange.imap.storecache;
 
+import static com.openexchange.imap.IMAPAccess.doIMAPConnect;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
 import com.sun.mail.imap.IMAPStore;
 
-
 /**
  * {@link AbstractIMAPStoreContainer}
  *
@@ -93,14 +93,14 @@ public abstract class AbstractIMAPStoreContainer implements IMAPStoreContainer {
          * ... and connect it
          */
         try {
-            imapStore.connect(server, port, login, pw);
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
         } catch (final AuthenticationFailedException e) {
             /*
              * Retry connect with AUTH=PLAIN disabled
              */
             imapSession.getProperties().put("mail.imap.auth.login.disable", "true");
             imapStore = (IMAPStore) imapSession.getStore(name);
-            imapStore.connect(server, port, login, pw);
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
         }
         return imapStore;
     }
